%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
% Funktion        : Handorientierung erkennen im Arbeitsraum              %
%                                                                         %
%                                                                         %
% Eingabe         : Hand: [x,y,z] Koordinate der Handmitte                %
%                   HandTip: [x,y,z] Koordinate der Handspitze            %
%                   Thumb: [x,y,z] Koordinate des Daumens                 %
%                                                                         %
%                                                                         %
% Ausgabe         : alpha: Winkel zwischen Handebene und YZ Ebene         %
%                   beta:  Winkel zwischen Handebene und XZ Ebene         %
%                   gamma: Winkel zwischen Handebene und XY Ebene         %
%                                                                         %
%                                                                         %
% Autor           : Kevin Penner                                          %
%                                                                         %
% Implementation  : MATLAB R2016b                                         %
%                                                                         %
% Bemerkung       :                                                       %
%                                                                         %
% nderungsdatum  : 10.05.2017                                            %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [alpha, beta, gamma] = HandOrientationWorkspace(Hand, HandTip, Thumb)

    %Ebene aufspannen mit den gegebenen 3 Punkten
    Hand_Plane = createPlane(Hand, HandTip, Thumb);
    
    %Orthogonalen Vektor herausfinden, welcher auf der Ebene liegt
    Hand_Normal = planeNormal(Hand_Plane);
        
    %Anlegen von drei Vetoren, welche die Koordinatenachsen reprsentieren
    Null = [0 0 0];
    x = [1 0 0];
    y = [0 1 0];
    z = [0 0 1];
    
    %Ebenen fr das Koordinatensystem anlegen
    XY_Plane = createPlane(Null, x, y);
    XZ_Plane = createPlane(Null, x, z);
    YZ_Plane = createPlane(Null, y, z);
    
    %Orthogonalen Vektor herausfinden, welcher auf der Ebene des
    %Koordinatensystems liegen
    XY_Normal = planeNormal(XY_Plane);
    XZ_Normal = planeNormal(XZ_Plane);
    YZ_Normal = planeNormal(YZ_Plane);
    
    %Winkel zwischen Handebene und Koordinatenebenen berechnen
    alpha = rad2deg(vectorAngle3d(Hand_Normal,YZ_Normal));
    beta = rad2deg(vectorAngle3d(Hand_Normal,XZ_Normal));
    gamma = rad2deg(vectorAngle3d(Hand_Normal,XY_Normal));
    

end